@@ -171,7 +171,7 @@ class Schema:
 
     @staticmethod
     def gen_schema_from_data(data):
-        generator = SchemaGenerator('dict')
+        generator = SchemaGenerator('dict', keep_nulls=True)
         schema_map, error_logs = generator.deduce_schema(data)
         if error_logs:
             raise PyGBQError('Could not generate schema, please provide a schema')
@@ -182,7 +182,7 @@ class Schema:
 class Update:
     """Initialize client.
     Usage:
-        Used as a helper class to store schema, how,  in update_table_using_temp
+        Used as a helper class to store `schema` and `how` in Client.update()
     """
 
     def __init__(self, client, how=None, table_id=None, schema=Schema(), expiration=None):
@@ -300,9 +300,8 @@ class Client:
         client.update_table(table_name, how)
     """
 
-    def __init__(self, default_dataset: str = None, save_dir: str = None, path_to_key: str = None):
+    def __init__(self, default_dataset: str = None, path_to_key: str = None):
         self.default_dataset = default_dataset
-        self.save_dir = save_dir
 
         credentials, self.project_id = load_credentials_from_file(
             path_to_key,
@@ -325,7 +324,7 @@ class Client:
 
     # TODO: dynamically set max_insert_num_rows
     # TODO: move all table_id, how, schema logic here to be able to call this function separately
-    def update_table_using_temp(
+    def update(
             self, data, table_id, how, schema: Union[str, List[dict]] = None,
             expiration=1, max_insert_num_rows=4000
     ):
@@ -357,7 +356,7 @@ class Client:
         if not isinstance(data, list):
             raise PyGBQError(f"Returned `{type(data)}`. Need `list`.")
 
-        table_id = self.set_table_id(table_id)
+        table_id = self._set_table_id(table_id)
 
         data_batches = [
             data[i * max_insert_num_rows: (i + 1) * max_insert_num_rows]
@@ -389,7 +388,7 @@ class Client:
                     update_insert.insert(data_batch=data_batch)
         return {"status": 200}
 
-    def set_table_id(self, table_id):
+    def _set_table_id(self, table_id):
         if not table_id:
             raise PyGBQNameError("'table_id' must be set")
         if not table_id.replace("_", "").replace(".", "").isalnum():
@@ -445,19 +444,19 @@ class Client:
             logging.exception(f"Your query '{query}' is incorrect")
         return message
 
-    def file_name_for_save(self, table_id, parameters, extension: str = ""):
-        """:arg extension: 'jsonl' or 'csv'"""
-        file_name = table_id
-        # TODO: drop chars not suitable for file name
-        if parameters:
-            len_kwargs = len(parameters)
-            file_name = file_name + "?"
-            for i, (arg, value) in enumerate(parameters.items()):
-                file_name = file_name + f"{arg}={value}"
-                if i < len_kwargs - 1:
-                    file_name = file_name + "&"
-        file_name = f"{file_name}.{extension}"
-        return Path(".") / self.save_dir / file_name
+    # def file_name_for_save(self, table_id, parameters, extension: str = ""):
+    #     """:arg extension: 'jsonl' or 'csv'"""
+    #     file_name = table_id
+    #     # TODO: drop chars not suitable for file name
+    #     if parameters:
+    #         len_kwargs = len(parameters)
+    #         file_name = file_name + "?"
+    #         for i, (arg, value) in enumerate(parameters.items()):
+    #             file_name = file_name + f"{arg}={value}"
+    #             if i < len_kwargs - 1:
+    #                 file_name = file_name + "&"
+    #     file_name = f"{file_name}.{extension}"
+    #     return Path(".") / self.save_dir / file_name
 
     def get_secret(self, secret_id, version="latest"):
         """
@@ -494,7 +493,7 @@ class Client:
     #     if not table:
     #         table = function.__name__
     #         print(table)
-    #     table_id = self.set_table_id(table)
+    #     table_id = self._set_table_id(table)
     #
     #     def inner(**kwargs):
     #         nonlocal how, schema
@@ -517,7 +516,7 @@ class Client:
     #                 save_data(data=data, name=name)
     #             if how:
     #                 if data:
-    #                     self.update_table_using_temp(data, table_id, how, schema)
+    #                     self.update(data, table_id, how, schema)
     #                     results["message"] = "success"
     #                 else:
     #                     logging.warning('Data is empty')
